/* Copyright (C) 1999-2000 Bernhard Trummer
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 *
 * $Log: textnode.h,v $
 * Revision 1.1.1.1  2001/01/30 18:36:46  slash
 * Initial release.
 *
 */

#ifndef TEXTNODE_H
#define TEXTNODE_H

#include "environmentnode.h"

//---------------------------------------------------------------------------
/**
 * This class represents a text-node.
 */
class TextNode : public EnvironmentNode {
  public:
    //-----------------------------------------------------------------------
    /**
     * The constructor initializes the text-node.
     *
     * @param node The XML-node, which represents the text-node.
     * @param with_margin indicates, if the HTML-output should have a margin.
     */
    TextNode(xmlNodePtr node,
             int with_margin = 1);

    //-----------------------------------------------------------------------
    /**
     * Destructor.
     */
    ~TextNode();


    //-----------------------------------------------------------------------
    /**
     * This method writes the node to the global output filestream Output_.
     * The format of the output must be HTML.
     * An integer-parameter has to be given because of the derivation,
     * but it won't be used in this class.
     *
     * @param parameter A dummy-parameter.
     */
    void writeHTML(int parameter = 0) const;

    //-----------------------------------------------------------------------
    /**
     * This method writes the node to the global output filestream Output_.
     * The format of the output must be LaTeX.
     */
    void writeLaTeX() const;

    //-----------------------------------------------------------------------
    /**
     * This method writes the node to the global output filestream Output_.
     * The format of the output must be XML.
     */
    void writeXML() const;

    //-----------------------------------------------------------------------
    /**
     * This method signals, if the HTML-output of the text-environment
     * should be stepped.
     *
     * @return 1, if the HTML-output should be stepped, else 0.
     *
     * @see getNumberOfHTMLSteps
     */
    int isHTMLStepped() const;

    //-----------------------------------------------------------------------
    /**
     * This method returns the number of steps of the HTML-output.
     *
     * @return The number of steps.
     */
    unsigned int getNumberOfHTMLSteps() const;


  private:

    //-----------------------------------------------------------------------
    /**
     * 1, if the HTML-output should have a margin, else 0.
     */
    int with_margin_;
};

#endif //TEXTNODE_H
